<?php
/**
 * Plugin Name: EP Upsell
 * Version:     1.0.0
 * Author:      Elektronika Perhoč
 * Author URI:  http://ep.hr/
 */

add_action('plugins_loaded', function() {
    $locale = get_locale();

    if (preg_match('/^de_/', $locale)) {
        $locale = 'de';
    }

    $mofile = __DIR__ . '/i18n/' . $locale . '.mo';

    if (file_exists($mofile)) {
        load_textdomain('ep-upsell', $mofile);
    }
});

add_action('ep_archive_after_content', function() {
    $category = get_queried_object();
    $container = ep_services();
    /** @var \Zend\ServiceManager\PluginManagerInterface $plugins */
    $plugins = $container->get(\Ep\Wp\Plugin\PluginManager::class);
    /** @var \Ep\Gath\Plugin\Products $gathProducts */
    $gathProducts = $plugins->get('gath.products');
    $gathProducts();

    if (!$category instanceof WP_Term) {
        return;
    }

    $posts = [];
    $bySku = [];

    if ($skus = get_term_meta($category->term_id, '_upsale_artcodes', true)) {
        $skus = explode(';', $skus);
        $_products = $gathProducts->getProductsBySkus($skus);

        if (count($_products) > 0) {
            foreach ($_products as $product) {
                $productSku = get_post_meta($product->ID, '_sku', true);
                $bySku[$productSku] = $product;
            }
        }

        foreach ($skus as $sku) {
            if (isset($bySku[$sku])) {
                $posts[] = $bySku[$sku];
            }
        }
    }

    $tecdoc = ep_tecdoc_service();
    /** @var \WC_Product[] $allProducts */
    $allProducts = [];
    $articlesByKey = [];

    if ($genArtIds = get_term_meta($category->term_id, '_upsale_tecdoc_artid', true)) {
        $genArtIds = array_map('absint', explode(';', $genArtIds));

        if (count($articles = $tecdoc->getArticlesByGenericIds($genArtIds)) > 0) {
            $articleKeys = [];
            $articlesByKey = [];

            foreach ($articles as $article) {
                $articleKeys[] = $article['key'];
                $articlesByKey[$article['key']] = $article;
            }

            $_products = $gathProducts->getProductsByTecDocKeys($articleKeys, 1, 1000, 0);

            foreach ($_products as $product) {
                $posts[] = $product;
            }
        }
    }

    foreach ($posts as $post) {
        if (!$post) continue;
        $product = wc_get_product($post);
        if (!$product->is_in_stock()) continue;
        $allProducts[] = $product;
    }

    if (count($allProducts) === 0) {
        return;
    }

    $products = $allProducts;
    $gathProducts = apply_filters('ep_gath_products', null);

    $plugins = $container->get(\Ep\Wp\Plugin\PluginManager::class);
    $gathImages = $plugins->get('gath.images');

    /** @var \Zend\ServiceManager\PluginManagerInterface $views */
    $views = $container->get(\Ep\Wp\View\ViewPluginManager::class);
    /** @var \Ep\Woo\Form\View\AddToCart $addToCart */
    $addToCart = $views->get('woo.form.addtocart');
    $addToCart->setUseIcon(true);

    include __DIR__ . '/templates/container.php';
});

add_action('wp_enqueue_scripts', function() {
    if (is_archive() && is_product_category()) {
        $manifest = json_decode(file_get_contents(__DIR__ . '/dist/manifest.json'), true);
        wp_enqueue_style('upsell', plugin_dir_url(__FILE__) . '/dist/' . $manifest['ep-upsell.css']);
        wp_enqueue_script('upsell', plugin_dir_url(__FILE__) . '/dist/' . $manifest['ep-upsell.js'], ['jquery'], '', true);
    }
});