const path = require('path');
const CleanPlugin = require('clean-webpack-plugin');
const ExtractTextPlugin = require('extract-text-webpack-plugin');
const LiveReloadPlugin = require('webpack-livereload-plugin');
const ManifestPlugin = require('webpack-manifest-plugin');
const ProvidePlugin = require('webpack/lib/ProvidePlugin');
const UglifyJSWebpackPlugin = require('uglifyjs-webpack-plugin');

module.exports = {
    entry: {
        'ep-upsell': './assets/js/main.js',
    },

    output: {
        filename: 'js/[name].[hash].js',
        path: path.resolve(__dirname, 'dist'),
    },

    plugins: [
        new CleanPlugin(['dist']),
        new ExtractTextPlugin({
            filename: 'css/[name].[hash].css'
        }),
        new ManifestPlugin(),
        new ProvidePlugin({
            jQuery: 'jquery',
        }),
        new UglifyJSWebpackPlugin(),
        new LiveReloadPlugin()
    ],

    module: {
        rules: [{
            test: /\.css$/,
            use: ExtractTextPlugin.extract({
                fallback: 'style-loader',
                use: [{
                    loader: 'css-loader',
                    options: {
                        importLoaders: 2,
                        sourceMap: true
                    }
                }]
            })
        }, {
            test: /\.scss$/,
            use: ExtractTextPlugin.extract({
                fallback: 'style-loader',
                use: [{
                    loader: 'css-loader',
                    options: {
                        importLoaders: 2,
                        sourceMap: true
                    }
                }, {
                    loader: 'postcss-loader',
                    options: {
                        ident: 'postcss',
                        sourceMap: true,
                        plugins: [
                            require('autoprefixer'),
                            require('cssnano')({
                                postcssReduceIdents: false,
                                zindex: false
                            })
                        ]
                    }
                }, {
                    loader: 'sass-loader',
                    options: {
                        sourceMap: true
                    }
                }]
            })
        }, {
            test: /\.js$/,
            loader: 'babel-loader',
            options: {
                presets: ['env']
            }
        }, {
            test: /\.(png|svg|jpg|gif)$/,
            use: [{
                loader: 'file-loader',
                options: {
                    name: 'img/[name].[ext]',
                    publicPath: '../'
                }
            }]
        }, {
            test: /\.(ttf|otf|eot|svg|woff(2)?)(\?[a-z0-9]+)?$/,
            use: [{
                loader: 'file-loader',
                options: {
                    name: 'font/[name].[ext]',
                    publicPath: '../'
                }
            }]
        }]
    },

    resolve: {
        alias: {
            jquery: 'jquery/src/jquery'
        }
    },

    externals: {
        jquery: 'jQuery'
    }
};